pub fn cast_time_ms(spell: &SpellDataFlat) -> i32Expand description
Cast time in ms; channeled spells store their duration in the duration slot.
pub fn cast_time_ms(spell: &SpellDataFlat) -> i32Cast time in ms; channeled spells store their duration in the duration slot.