pub fn extract_damage_payload(spell: &SpellDataFlat) -> Option<TriggerPayload>Expand description
Extract the damage coefficient payload from a spell, preferring direct school damage over the first periodic-damage aura.
pub fn extract_damage_payload(spell: &SpellDataFlat) -> Option<TriggerPayload>Extract the damage coefficient payload from a spell, preferring direct school damage over the first periodic-damage aura.