pub fn health_cost<S>(
spell: &SpellDataFlat,
active_aura_spell_ids: &HashSet<i32, S>,
) -> HealthCostswhere
S: BuildHasher,Expand description
Flat, percentage, and optional health costs from the active health-power row.
pub fn health_cost<S>(
spell: &SpellDataFlat,
active_aura_spell_ids: &HashSet<i32, S>,
) -> HealthCostswhere
S: BuildHasher,Flat, percentage, and optional health costs from the active health-power row.